kedro.pipeline — Kedro 0.17.6 documentation

# kedro.pipeline

Description

`kedro.pipeline` provides functionality to define and execute data-driven pipelines.

Functions

`kedro.pipeline.node`(func, inputs, outputs, *) | Create a node in the pipeline by providing a function to be called along with variable names for inputs and/or outputs.
`kedro.pipeline.modular_pipeline.pipeline`(pipe, *) | Create a copy of the pipeline and its nodes, with some dataset names and node names modified.

Classes

`kedro.pipeline.Pipeline`(nodes, *[, tags]) | A `Pipeline` defined as a collection of `Node` objects.
`kedro.pipeline.node.Node`(func, inputs, …) | `Node` is an auxiliary class facilitating the operations required to run user-provided functions as part of Kedro pipelines.

Modules

`kedro.pipeline.decorators` | A module containing predefined node decorators in Kedro.

Exceptions

`kedro.pipeline.modular_pipeline.ModularPipelineError` | Raised when a modular pipeline is not adapted and integrated appropriately using the helper.